@@ -5,8 +5,11 @@
 #
 # export GI_TYPELIB_PATH=$GI_TYPELIB_PATH:/usr/local/lib/girepository-1.0/
 
+import gi
+gi.require_version('GtkChamplain', '0.12')
+gi.require_version('GtkClutter', '1.0')
 from gi.repository import GtkClutter
-from gi.repository import GObject, Gtk, GtkChamplain 
+from gi.repository import Gtk, GtkChamplain
 
 GtkClutter.init([])
 
@@ -20,4 +23,3 @@ window.add(widget)
 window.show_all()
 
 Gtk.main()
-
